% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/polar_freqMap.R
\name{freqMap}
\alias{freqMap}
\title{Polar frequency plots on interactive leaflet maps}
\usage{
freqMap(
  data,
  pollutant = NULL,
  breaks = NULL,
  statistic = "mean",
  latitude = NULL,
  longitude = NULL,
  control = NULL,
  popup = NULL,
  label = NULL,
  provider = "OpenStreetMap",
  cols = "turbo",
  alpha = 1,
  key = FALSE,
  draw.legend = TRUE,
  collapse.control = FALSE,
  d.icon = 200,
  d.fig = 3.5,
  type = NULL,
  ...
)
}
\arguments{
\item{data}{A data frame. The data frame must contain the data to plot the
directional analysis marker, which includes wind speed (\code{ws}), wind
direction (\code{wd}), and the column representing the concentration of a
pollutant. In addition, \code{data} must include a decimal latitude and
longitude.}

\item{pollutant}{The column name(s) of the pollutant(s) to plot. If multiple
pollutants are specified, they can be toggled between using a "layer
control" interface.}

\item{breaks}{The user can provide their own scale. breaks expects a sequence
of numbers that define the range of the scale. The sequence could represent
one with equal spacing, e.g., \code{breaks = seq(0, 100, 10)} - a scale from
0-10 in intervals of 10, or a more flexible sequence, e.g., \code{breaks = c(0, 1, 5, 7, 10)}, which may be useful for some situations.}

\item{statistic}{The statistic that should be applied to each wind
speed/direction bin. Can be "frequency", "mean", "median", "max" (maximum),
"stdev" (standard deviation) or "weighted.mean". The option "frequency" is
the simplest and plots the frequency of wind speed/direction in different
bins. The scale therefore shows the counts in each bin. The option "mean"
(the default) will plot the mean concentration of a pollutant (see next
point) in wind speed/direction bins, and so on.  Finally, "weighted.mean"
will plot the concentration of a pollutant weighted by wind
speed/direction. Each segment therefore provides the percentage overall
contribution to the total concentration. Note that for options other than
"frequency", it is necessary to also provide the name of a pollutant. See
function \code{\link[openair:cutData]{openair::cutData()}} for further details.}

\item{latitude, longitude}{The decimal latitude/longitude. If not provided,
will be automatically inferred from data by looking for a column named
"lat"/"latitude" or "lon"/"lng"/"long"/"longitude" (case-insensitively).}

\item{control}{Column to be used for splitting the input data into different
groups which can be selected between using a "layer control" interface.
Appropriate columns could be those added by \code{\link[openair:cutData]{openair::cutData()}} or
\code{\link[openair:splitByDate]{openair::splitByDate()}}. \code{control} cannot be used if multiple \code{pollutant}
columns have been provided.}

\item{popup}{Column to be used as the HTML content for marker popups. Popups
may be useful to show information about the individual sites (e.g., site
names, codes, types, etc.).}

\item{label}{Column to be used as the HTML content for hover-over labels.
Labels are useful for the same reasons as popups, though are typically
shorter.}

\item{provider}{The base map(s) to be used. See
\url{http://leaflet-extras.github.io/leaflet-providers/preview/} for a list of
all base maps that can be used. If multiple base maps are provided, they
can be toggled between using a "layer control" interface.}

\item{cols}{The colours used for plotting. See \code{\link[openair:openColours]{openair::openColours()}} for
more information.}

\item{alpha}{The alpha transparency to use for the plotting surface (a value
between 0 and 1 with zero being fully transparent and 1 fully opaque).}

\item{key}{Should a key for each marker be drawn? Default is \code{FALSE}.}

\item{draw.legend}{When \code{breaks} are specified, should a shared legend be
created at the side of the map? Default is \code{TRUE}.}

\item{collapse.control}{Should the "layer control" interface be collapsed?
Defaults to \code{FALSE}.}

\item{d.icon}{The diameter of the plot on the map in pixels. This will affect
the size of the individual polar markers. Alternatively, a vector in the
form \code{c(width, height)} can be provided if a non-circular marker is
desired.}

\item{d.fig}{The diameter of the plots to be produced using \code{openair} in
inches. This will affect the resolution of the markers on the map.
Alternatively, a vector in the form \code{c(width, height)} can be provided if a
non-circular marker is desired.}

\item{type}{Deprecated. Please use \code{label} and/or \code{popup} to label different
sites.}

\item{...}{
  Arguments passed on to \code{\link[openair:polarFreq]{openair::polarFreq}}
  \describe{
    \item{\code{ws.int}}{Wind speed interval assumed. In some cases e.g. a low met
mast, an interval of 0.5 may be more appropriate.}
    \item{\code{wd.nint}}{Number of intervals of wind direction.}
    \item{\code{grid.line}}{Radial spacing of grid lines.}
    \item{\code{trans}}{Should a transformation be applied? Sometimes when producing
plots of this kind they can be dominated by a few high points. The default
therefore is \code{TRUE} and a square-root transform is applied. This
results in a non-linear scale and (usually) a better representation of the
distribution. If set to \code{FALSE} a linear scale is used.}
    \item{\code{min.bin}}{The minimum number of points allowed in a wind speed/wind
direction bin.  The default is 1. A value of two requires at least 2 valid
records in each bin an so on; bins with less than 2 valid records are set
to NA. Care should be taken when using a value > 1 because of the risk of
removing real data points. It is recommended to consider your data with
care. Also, the \code{polarFreq} function can be of use in such
circumstances.}
    \item{\code{ws.upper}}{A user-defined upper wind speed to use. This is useful for
ensuring a consistent scale between different plots. For example, to
always ensure that wind speeds are displayed between 1-10, set
\code{ws.int = 10}.}
    \item{\code{offset}}{\code{offset} controls the size of the \sQuote{hole} in the
middle and is expressed as a percentage of the maximum wind speed. Setting
a higher \code{offset} e.g. 50 is useful for \code{statistic =
  "weighted.mean"} when \code{ws.int} is greater than the maximum wind
speed. See example below.}
    \item{\code{border.col}}{The colour of the boundary of each wind speed/direction
bin. The default is transparent. Another useful choice sometimes is
"white".}
    \item{\code{key.header}}{Adds additional text/labels to the scale key. For example,
passing the options \code{key.header = "header", key.footer = "footer1"}
adds addition text above and below the scale key. These arguments are
passed to \code{drawOpenKey} via \code{quickText}, applying the
\code{auto.text} argument, to handle formatting.}
    \item{\code{key.footer}}{see \code{key.footer}.}
    \item{\code{key.position}}{Location where the scale key is to plotted. Allowed
arguments currently include \code{"top"}, \code{"right"}, \code{"bottom"}
and \code{"left"}.}
    \item{\code{auto.text}}{Either \code{TRUE} (default) or \code{FALSE}. If \code{TRUE}
titles and axis labels will automatically try and format pollutant names
and units properly e.g.  by subscripting the `2' in NO2.}
  }}
}
\value{
A leaflet object.
}
\description{
\code{\link[=freqMap]{freqMap()}} creates a \code{leaflet} map using binned polar plots as markers. Any
number of pollutants can be specified using the \code{pollutant} argument, and
multiple layers of markers can be added and toggled between using \code{control}.
}
\examples{
\dontrun{
freqMap(polar_data,
  pollutant = "nox",
  statistic = "mean",
  provider = "Stamen.Toner"
)
}
}
\seealso{
the original \code{\link[openair:polarFreq]{openair::polarFreq()}}

\code{\link[=freqMapStatic]{freqMapStatic()}} for the static \code{ggmap} equivalent of
\code{\link[=freqMap]{freqMap()}}

Other interactive directional analysis maps: 
\code{\link{annulusMap}()},
\code{\link{diffMap}()},
\code{\link{percentileMap}()},
\code{\link{polarMap}()},
\code{\link{pollroseMap}()},
\code{\link{windroseMap}()}
}
\concept{interactive directional analysis maps}
